<?php

namespace App\Controller\Api;

use App\Controller\Control;
use App\Http\HttpRequest;
use App\Http\HttpResponse;
use App\Http\JsonHttpResponse;
use App\Model\AuthModel;
use App\Validation\Validators;

class APIAuthController {
    private AuthModel $model;

    /**
     * @param AuthModel $model
     */
    public function __construct(AuthModel $model) {
        $this->model = $model;
    }


    public function authorize(): HttpResponse {
        return Control::runChecked([
            "email" => [Validators::regex("/^\\S+@\\S+\\.\\S+$/"), Validators::lenBetween(5, 256)],
            "password" => [Validators::lenBetween(6, 256)],
        ], function (HttpRequest $req) {
            $failures = [];
            $account = $this->model->login($req["email"], $req["password"], $failures);

            if (!empty($failures)) {
                return new JsonHttpResponse($failures);
            }

            return new JsonHttpResponse(["authorization" => $account->getToken()]);
        }, true);
    }

}
