<?php

namespace App\Controller;

use App\Connexion;
use App\Gateway\TacticInfoGateway;
use App\Gateway\TeamGateway;
use App\Http\HttpResponse;
use App\Http\ViewHttpResponse;
use App\Model\TacticModel;
use App\Model\TeamModel;
use App\Session\SessionHandle;

class UserController extends VisitorController {

    public function home(): HttpResponse {
        return ViewHttpResponse::twig("home.twig", []);
    }

    public function view(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\VisualizerController($model))->visualize($id, $session);
    }

    public function edit(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\EditorController($model))->edit($id, $session);
    }

    public function create(SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\EditorController($model))->createNew($session);
    }

    public function open(int $id, SessionHandle $session): HttpResponse {
        $model = new TacticModel(new TacticInfoGateway(new Connexion(get_database())));
        return (new Sub\VisualizerController($model))->visualize($id, $session);
    }

    public function createTeam(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displaySubmitTeam();
        }
        return $ctrl->submitTeam($_POST);
    }

    public function listTeams(): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            return $ctrl->displayListTeamByName();
        }
        return $ctrl->listTeamByName($_POST);
    }

    public function getTeam(int $id): HttpResponse {
        $model = new TeamModel(new TeamGateway(new Connexion(get_database())));
        $ctrl = new Sub\TeamController($model);
        return $ctrl->getTeam($id);
    }
}
